@@ -2,7 +2,7 @@
 
 # d to es
 
-d_to_es <- function(d, n.1, n.2) {
+des <- function(d, n.1, n.2) {
   var.d<-(n.1+n.2)/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2
   j<-1-(3/(4*df-1))
@@ -12,8 +12,8 @@ d_to_es <- function(d, n.1, n.2) {
   n <- n.1 + n.2
   r <- d/sqrt((d^2) + a) # to compute r from d
   var.r <- (a^2*var.d)/(d^2 + a)^3
-  lor <- pi*d/sqrt(3)
-  var.lor <- pi^2*var.d/3
+  lor <- d*(pi/sqrt(3))
+  var.lor <- var.d*(pi^2/3)
   z <-  0.5*log((1 + r)/(1-r))  
   var.z <- 1/(n-3) 
   #z.score <- r/sqrt(var.r)
@@ -34,9 +34,9 @@ d_to_es <- function(d, n.1, n.2) {
 # m.1 (post-test mean of treatment), m.2 (post-test mean of comparison),
 # sd.1 (treatment standard deviation at post-test), sd.2 (comparison 
 # standard deviation at post-test), n.1 (treatment), n.2 (comparison/control).
-# WAS MEAN TO D
 
-mean_to_es <- function(m.1,m.2,sd.1,sd.2,n.1, n.2) {
+
+mes <- function(m.1,m.2,sd.1,sd.2,n.1, n.2) {
   s.within<-sqrt(((n.1-1)*sd.1^2+(n.2-1)*sd.2^2)/(n.1+n.2-2))
   d<-(m.1-m.2)/s.within
   var.d<-(n.1+n.2)/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
@@ -66,7 +66,7 @@ mean_to_es <- function(m.1,m.2,sd.1,sd.2,n.1, n.2) {
 # s.pooled (pooled standard deviation), n.1 (treatment), 
 # n.2 (comparison/control).
 
-mean_to_es2 <- function(m.1,m.2,s.pooled,n.1, n.2) {
+mes2 <- function(m.1,m.2,s.pooled,n.1, n.2) {
   d<-(m.1-m.2)/s.pooled
   var.d<-(n.1+n.2)/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2
@@ -94,7 +94,7 @@ mean_to_es2 <- function(m.1,m.2,s.pooled,n.1, n.2) {
 # t (t-test value of treatment v comparison), n.1 (treatment),
 # n.2 (comparison/control).
 
-tt_to_es <- function(t, n.1, n.2) { #If only total n reported just split .5
+tes <- function(t, n.1, n.2) { #If only total n reported just split .5
   d<-t*sqrt((n.1+n.2)/(n.1*n.2))
   var.d<-(n.1+n.2)/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2
@@ -121,7 +121,7 @@ tt_to_es <- function(t, n.1, n.2) { #If only total n reported just split .5
 # n.2 (comparison/control).
 
 
-f_to_es <- function(f,n.1, n.2) {
+fes <- function(f,n.1, n.2) {
   d<-sqrt(f*(n.1+n.2)/(n.1*n.2))
   var.d<-(n.1+n.2)/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2
@@ -150,7 +150,7 @@ f_to_es <- function(f,n.1, n.2) {
 # (4) Study reported: 
 # p-value,  n.1 (treatment), n.2 (comparison/control), tail (one or two tailed?).
 
-p_to_es <- function(p, n.1, n.2, tail = "two") {
+pes <- function(p, n.1, n.2, tail = "two") {
   n <- n.1 + n.2
   df<- (n.1+n.2)-2
   j<-1-(3/(4*df-1))
@@ -194,11 +194,12 @@ p_to_es <- function(p, n.1, n.2, tail = "two") {
 
 
 #  Pearson r to effect size.
-r_to_es <- function(r, var.r = NULL, n ) { # If var.r not reported use n
+res <- function(r, var.r = NULL, n ) { # If var.r not reported use n
   if(missing(var.r)){
     r <- r
     var.r <-(1-r^2)^2/(n-1) 
-    d<-2*r*sqrt((n-1)/(n*(1-r^2)))*abs(r)/r 
+    #d<-2*r*sqrt((n-1)/(n*(1-r^2)))*abs(r)/r 
+    d <- (2*r)/(sqrt(1-r^2))
     var.d <- 4*var.r/(1-r^2)^3
     lor <- pi*d/sqrt(3)
     var.lor <- pi^2*var.d/3
@@ -231,7 +232,7 @@ r_to_es <- function(r, var.r = NULL, n ) { # If var.r not reported use n
 # n.2 (comparison/control), R (covariate outcome correlation or multiple
 # correlation), q (number of covariates).
 
-mean_anc_to_es <- function(m.1.adj,m.2.adj,sd.adj,n.1, n.2, R, q) {
+a.mes <- function(m.1.adj,m.2.adj,sd.adj,n.1, n.2, R, q) {
    s.within<-sd.adj/sqrt(1-R^2)
    d<-(m.1.adj-m.2.adj)/s.within
    var.d<-((n.1+n.2)*(1-R^2))/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
@@ -263,7 +264,7 @@ mean_anc_to_es <- function(m.1.adj,m.2.adj,sd.adj,n.1, n.2, R, q) {
 # n.2 (comparison/control), R (covariate outcome correlation or multiple
 # correlation), q (number of covariates).
 
-mean_anc_to_es2 <- function(m.1.adj, m.2.adj, s.pooled, n.1, n.2, R, q) {
+a.mes2 <- function(m.1.adj, m.2.adj, s.pooled, n.1, n.2, R, q) {
   d<-(m.1.adj-m.2.adj)/s.pooled
   var.d<-((n.1+n.2)*(1-R^2))/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2 - q
@@ -293,7 +294,7 @@ mean_anc_to_es2 <- function(m.1.adj, m.2.adj, s.pooled, n.1, n.2, R, q) {
 # n.2 (comparison/control), R (covariate outcome correlation or multiple
 # correlation), q (number of covariates).
 
-tt.ancova_to_es <- function(t, n.1, n.2, R, q) {
+a.tes <- function(t, n.1, n.2, R, q) {
   d<-t*sqrt((n.1+n.2)/(n.1*n.2))*sqrt(1-R^2)
   var.d<-((n.1+n.2)*(1-R^2))/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2 - q
@@ -319,11 +320,11 @@ tt.ancova_to_es <- function(t, n.1, n.2, R, q) {
 }
 
 # Study reported: 
-# f (F-test value from ANCOVA), n.1 (treatment),
+# f (F-test value from ANCOVA) with independent groups, n.1 (treatment),
 # n.2 (comparison/control),R (covariate outcome correlation or multiple
 # correlation), q (number of covariates).
 
-f.ancova_to_es<-function(f,n.1, n.2, R, q) {
+a.fes<-function(f,n.1, n.2, R, q) {
   d<-sqrt(f*(n.1+n.2)/(n.1*n.2))*sqrt(1-R^2)
   var.d<-((n.1+n.2)*(1-R^2))/(n.1*n.2)+ (d^2)/(2*(n.1+n.2))
   df<- (n.1+n.2)-2 - q
@@ -353,7 +354,7 @@ f.ancova_to_es<-function(f,n.1, n.2, R, q) {
 # n.2 (comparison/control), R (covariate outcome correlation or multiple
 # correlation), q (number of covariates).
 
-p.ancova_to_es <- function(p, n.1, n.2, R, q, tail = "two") {
+a.pes <- function(p, n.1, n.2, R, q, tail = "two") {
   n <- n.1 + n.2
   df<- (n.1+n.2)-2 - q
   j<-1-(3/(4*df-1))
@@ -395,7 +396,7 @@ p.ancova_to_es <- function(p, n.1, n.2, R, q, tail = "two") {
 
 # computing es from log odds ratio
 
-lor_to_es <- function(lor, var.lor, n.1, n.2) { # n.1 =  tmt grp
+lores <- function(lor, var.lor, n.1, n.2) { # n.1 =  tmt grp
   d <- lor*sqrt(3)/pi
   var.d <- 3*var.lor/pi^2
   df<- (n.1+n.2)-2 
@@ -421,7 +422,7 @@ lor_to_es <- function(lor, var.lor, n.1, n.2) { # n.1 =  tmt grp
 
 # compute or from proportions
 
-prop_to_es <- function(p1, p2, n.ab, n.cd) {
+propes <- function(p1, p2, n.ab, n.cd) {
   or <-(p1*(1-p2))/(p2*(1-p1))
   lor <- log(or)
   var.lor <- 1/(n.ab*p1*(1-p1))+1/(n.cd*p2*(1-p2))
@@ -449,11 +450,11 @@ prop_to_es <- function(p1, p2, n.ab, n.cd) {
 }
 
 
-# Odds Ratio to d: if have info for 'failure' in both conditions 
+# Odds Ratio to es: if have info for 'failure' in both conditions 
 # (B = # tmt failure; D = # non-tmt failure) and the sample size
 # for each group (n.1 & n.0 respectively):
 
-fail_to_es <- function(B, D, n.1, n.0) {
+failes <- function(B, D, n.1, n.0) {
   A <- n.1 - B  # tmt success
   B <- B        # tmt failure
   C <- n.0 - D  # non-tmt success
@@ -492,7 +493,7 @@ fail_to_es <- function(B, D, n.1, n.0) {
 
 # Converting Chi-squared statistic with 1 df to es
 
-chi_to_es <- function(chi.sq,  n) {
+chies <- function(chi.sq,  n) {
   r <- sqrt(chi.sq/n)
   var.r <-(1-r^2)^2/(n-1) 
   d<-2*r*sqrt((n-1)/(n*(1-r^2)))*abs(r)/r 
